@@ -7,14 +7,13 @@ import pymongo
 import pytz
 import numpy as np
 
-
-
-class MongoTimeseries(object):
+class MongoCache(object):
     def __init__(self, mongo_collection, metric):
         self._ensure_indexes(mongo_collection)
         self._collection = mongo_collection
         self._metric = metric
-        
+
+class MongoTimeseries(MongoCache):
     @classmethod
     def _ensure_indexes(cls, collection):
         collection.ensure_index([('date', pymongo.ASCENDING), 
@@ -26,7 +25,8 @@ class MongoTimeseries(object):
                                          'date' : {'$in' : dates},
                                          }).sort('symbol')
         for record in records:
-            yield self._beautify_record(record, self._metric)
+            yield (record['date'].replace(tzinfo=pytz.UTC), 
+                   np.float(record[self._metric]))
         
     def set(self, symbol, records):
         for date, value in records:
@@ -41,21 +41,9 @@ class MongoTimeseries(object):
         client = pymongo.MongoClient(host, port)
         collection = client.prices.prices
         return cls(collection, 'price')
-    
-    @staticmethod
-    def _beautify_record(record, metric):
-        '''Cast metric to np.float and make date tz-aware.
-        
-        '''
-
-        return record['date'].replace(tzinfo=pytz.UTC), np.float(record[metric])
         
         
 class MongoIntervalseries(MongoTimeseries):
-    def __init__(self, collection, metric): 
-        super(MongoIntervalseries, self).__init__(mongo_collection=collection,
-                                                  metric=metric)
-    
     @classmethod
     def _ensure_indexes(cls, collection):
         collection.ensure_index([('start', pymongo.ASCENDING),
@@ -63,23 +51,25 @@ class MongoIntervalseries(MongoTimeseries):
                                  ('symbol', pymongo.ASCENDING)])
         
     def get(self, symbol, date):
-        cursor = self._collection.find({'symbol' : symbol,
+        document = self._collection.find_one({'symbol' : symbol,
                                         'start' : {'$lte' : date},
                                         '$or' : [{'end' : {'$gte' : date}},
                                                   {'end' : None}],
                                         }
                                          )
-        try:
-            record = cursor.next()
-        except StopIteration:
-            return None
-        else:
-            return np.float(record[self._metric])
+        if document:
+            metric_value = document.get(self._metric)
+            if metric_value:
+                return np.float(metric_value)
+        return None
                     
     def set_interval(self, symbol, start, end, value):
-        data = {'symbol' : symbol,
+        spec = {'symbol' : symbol,
                 'start' : start,
                 'end' : end,
-                self._metric : value}
-        self._collection.insert(data)
-
+                } 
+        data = {self._metric : value}
+        self._collection.update(spec=spec,
+                                document={'$set' : data},
+                                upsert=True)
+        
\ No newline at end of file
